
======================  =========================  ===========================================================================================  =====================  ========================================================================================================================================================================================
Key                     Type                       Options                                                                                      Default                Description                                                                                                                                                                             
======================  =========================  ===========================================================================================  =====================  ========================================================================================================================================================================================
``guess_redshift``      ndarray, list, int, float  ..                                                                                           0.0                    Initial guess for the redshift (:math:`cz`) of each binned spectrum.                                                                                                                    
``guess_dispersion``    ndarray, list, int, float  ..                                                                                           100.0                  Initial guess for the velocity dispersion for each binned spectrum.                                                                                                                     
``iteration_mode``      str                        ``none``, ``no_global_wrej``, ``global_template``, ``nonzero_templates``, ``all_templates``  ``nonzero_templates``  Iteration mode to use; see :func:`PPXFFit.iteration_modes`.                                                                                                                             
``template_library``    str, TemplateLibraryDef    ..                                                                                           ``MILESHC``            Keyword identifier or definition object used to build the spectral template library used during the fit.                                                                                
``matched_resolution``  bool                       ..                                                                                           False                  Flag that the spectral resolution of the templates are (should be) matched to the galaxy data.                                                                                          
``pixelmask``           PixelMask                  ..                                                                                           ..                     Pixel mask to include during the fitting; see :func:`~mangadap.util.pixelmask.SpectralPixelMask`.                                                                                       
``reject_boxcar``       int                        ..                                                                                           100                    Number of pixels in the boxcar used to determine the local sigma for rejecting outliers.                                                                                                
``velscale_ratio``      int                        ..                                                                                           1                      The **integer** ratio between the velocity scale of the pixel in the galaxy data to that of the template data.                                                                          
``bias``                int, float                 ..                                                                                           ..                     `ppxf`_ ``bias`` parameter used to penalize low S/N spectra toward a Gaussian LOSVD.                                                                                                    
``degree``              int                        ..                                                                                           8                      `ppxf`_ ``degree`` parameter used to set the order of the additive polynomial to include in the fit.                                                                                    
``mdegree``             int                        ..                                                                                           0                      `ppxf`_ ``mdegree`` parameter used to set the order of the multiplicative polynomial to include in the fit.                                                                             
``moments``             int                        2, 4, 6                                                                                      2                      `ppxf`_ ``moments`` parameter used to set the number of moments of the LOSVD to fit.  The DAP has not been well tested for fits that include any more than :math:`V` and :math:`\sigma`.
======================  =========================  ===========================================================================================  =====================  ========================================================================================================================================================================================

